'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const vscode_languageclient_1 = require("vscode-languageclient");
/**
 * vs-code plugin API implementation
 * this is the main entry point for the vs studio code extension API
 * see https://code.visualstudio.com/docs/extensionAPI/activation-events
 */
function activate(context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let serverModule = require.resolve('./lib/server.js'); //context.asAbsolutePath(path.join('dist', 'src', 'server', 'server.js'));
        // let debugOptions = {execArgv: ['']};
        let debugOptions = { execArgv: ['--inspect'] }; // Turn on debugging messages in output
        let serverOptions = {
            run: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc },
            debug: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc, options: debugOptions, runtime: 'node' }
        };
        let clientOptions = {
            documentSelector: [{ language: 'stylable' }, { language: 'typescript' }, { language: 'javascript' },],
            diagnosticCollectionName: 'stylable',
        };
        const client = new vscode_languageclient_1.LanguageClient('stylable', serverOptions, clientOptions);
        client.trace = vscode_jsonrpc_1.Trace.Verbose; // Elevate debugging message info in output
        context.subscriptions.push(client.start());
        yield client.onReady();
        // const files = await workspace.findFiles('**/*.st.css');
        // await Promise.all(files.map((file: any) => workspace.openTextDocument(file.fsPath)));
        return client;
    });
}
exports.activate = activate;
/**
 * vs-code plugin API implementation
 * deactivation cleanup
 */
function deactivate() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
    });
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map