"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@stylable/core");
class Completion {
    constructor(label, detail = "", sortText = 'd', insertText = label, range, additionalCompletions = false, triggerSignature = false) {
        this.label = label;
        this.detail = detail;
        this.sortText = sortText;
        this.insertText = insertText;
        this.range = range;
        this.additionalCompletions = additionalCompletions;
        this.triggerSignature = triggerSignature;
    }
}
exports.Completion = Completion;
class snippet {
    constructor(source) {
        this.source = source;
    }
}
exports.snippet = snippet;
exports.importDirectives = {
    from: core_1.valueMapping.from,
    default: core_1.valueMapping.default,
    named: core_1.valueMapping.named,
};
exports.rulesetDirectives = {
    extends: core_1.valueMapping.extends,
    mixin: core_1.valueMapping.mixin,
    states: core_1.valueMapping.states,
};
exports.topLevelDirectives = {
    root: '.root',
    namespace: '@namespace',
    customSelector: '@custom-selector :--',
    vars: ':vars',
    import: ':import'
};
//syntactic
function importInternalDirective(type, rng) {
    switch (exports.importDirectives[type]) {
        case core_1.valueMapping.default:
            return new Completion(core_1.valueMapping.default + ':', 'Default export name', 'a', new snippet(core_1.valueMapping.default + ': $1;'), rng);
        case core_1.valueMapping.from:
            return new Completion(core_1.valueMapping.from + ':', 'Path to library', 'a', new snippet(core_1.valueMapping.from + ': "$1";'), rng);
        case core_1.valueMapping.named:
            return new Completion(core_1.valueMapping.named + ':', 'Named export name', 'a', new snippet(core_1.valueMapping.named + ': $1;'), rng);
    }
}
exports.importInternalDirective = importInternalDirective;
function rulesetInternalDirective(type, rng) {
    switch (exports.rulesetDirectives[type]) {
        case core_1.valueMapping.extends:
            return new Completion(core_1.valueMapping.extends + ':', 'Extend an external component', 'a', new snippet('-st-extends: $1;'), rng, true);
        case core_1.valueMapping.mixin:
            return new Completion(core_1.valueMapping.mixin + ':', 'Apply mixins on the class', 'a', new snippet('-st-mixin: $1;'), rng, true);
        case core_1.valueMapping.states:
            return new Completion(core_1.valueMapping.states + ':', 'Define the CSS states available for this class', 'a', new snippet('-st-states: $1;'), rng);
    }
}
exports.rulesetInternalDirective = rulesetInternalDirective;
function topLevelDirective(type, rng) {
    switch (exports.topLevelDirectives[type]) {
        case exports.topLevelDirectives.import:
            return new Completion(exports.topLevelDirectives.import, 'Import an external library', 'a', new snippet(':import {\n\t-st-from: "$1";\n}$0'), rng);
        case exports.topLevelDirectives.namespace:
            return new Completion(exports.topLevelDirectives.namespace, 'Declare a namespace for the file', 'a', new snippet('@namespace "$1";\n$0'), rng);
        case exports.topLevelDirectives.customSelector:
            return new Completion(exports.topLevelDirectives.customSelector.slice(0, -4), 'Define a custom selector', 'a', exports.topLevelDirectives.customSelector, rng);
        case exports.topLevelDirectives.root:
            return new Completion(exports.topLevelDirectives.root, 'The root class', 'a', undefined, rng);
        case exports.topLevelDirectives.vars:
            return new Completion(exports.topLevelDirectives.vars, 'Declare variables', 'a', new snippet(':vars {\n\t$1\n}$0'), rng);
    }
}
exports.topLevelDirective = topLevelDirective;
function valueDirective(rng) {
    return new Completion('value()', 'Use the value of a variable', 'a', new snippet(' value($1)$0'), rng);
}
exports.valueDirective = valueDirective;
function globalCompletion(rng) {
    return new Completion(':global()', 'Target a global selector', 'a', new snippet(':global($0)'), rng);
}
exports.globalCompletion = globalCompletion;
//semantic
function classCompletion(className, rng, removeDot = false) {
    return new Completion((removeDot ? '' : '.') + className, 'Stylable class or tag', 'a', undefined, rng);
}
exports.classCompletion = classCompletion;
function extendCompletion(symbolName, from, rng) {
    return new Completion(symbolName, 'from: ' + from, 'a', new snippet(symbolName), rng);
}
exports.extendCompletion = extendCompletion;
function namedCompletion(symbolName, rng, from, value) {
    return new Completion(symbolName, 'from: ' + from + '\n' + 'Value: ' + value, 'a', new snippet(symbolName), rng);
}
exports.namedCompletion = namedCompletion;
function cssMixinCompletion(symbolName, rng, from) {
    return new Completion(symbolName, 'from: ' + from, 'a', new snippet(symbolName), rng);
}
exports.cssMixinCompletion = cssMixinCompletion;
function codeMixinCompletion(symbolName, rng, from) {
    return new Completion(symbolName, 'from: ' + from, 'a', new snippet(symbolName + "($0)"), rng, false, true);
}
exports.codeMixinCompletion = codeMixinCompletion;
function formatterCompletion(symbolName, rng, from) {
    return new Completion(symbolName, 'from: ' + from, 'a', new snippet(symbolName + "($0)"), rng, false, true);
}
exports.formatterCompletion = formatterCompletion;
function pseudoElementCompletion(elementName, from, rng) {
    return new Completion('::' + elementName, 'from: ' + from, 'a', '::' + elementName, rng);
}
exports.pseudoElementCompletion = pseudoElementCompletion;
function stateTypeCompletion(type, from, rng) {
    return new Completion(`${type}()`, `from: ${from}`, 'a', new snippet(`${type}($0)`), rng, false);
}
exports.stateTypeCompletion = stateTypeCompletion;
function stateCompletion(stateName, from, rng, type, hasParam) {
    return new Completion(':' + stateName + (hasParam ? '()' : ''), 'from: ' + from, 'a', new snippet(':' + stateName + (hasParam ? '($1)$0' : '')), rng, type === 'enum', hasParam);
}
exports.stateCompletion = stateCompletion;
function stateEnumCompletion(option, from, rng) {
    return new Completion(option, 'from: ' + from, 'a', new snippet(option), rng, false);
}
exports.stateEnumCompletion = stateEnumCompletion;
function valueCompletion(name, from, value, rng) {
    return new Completion(name, 'from: ' + from + '\n' + 'value: ' + value, 'a', new snippet(name), rng);
}
exports.valueCompletion = valueCompletion;
//# sourceMappingURL=completion-types.js.map