import * as PostCss from 'postcss';
import { CSSResolve, Stylable, StylableMeta } from '@stylable/core';
import * as ts from 'typescript';
import { Location, ParameterInformation, Position, ReferenceParams, SignatureHelp } from 'vscode-languageserver';
import { ProviderPosition, ProviderRange } from './completion-providers';
import { Completion } from './completion-types';
import { ExtendedFSReadSync, ExtendedTsLanguageService } from './types';
export default class Provider {
    private styl;
    private tsLangService;
    constructor(styl: Stylable, tsLangService: ExtendedTsLanguageService);
    private providers;
    provideCompletionItemsFromSrc(src: string, pos: Position, fileName: string, fs: ExtendedFSReadSync): Completion[];
    getDefinitionLocation(src: string, position: ProviderPosition, filePath: string, fs: ExtendedFSReadSync): Thenable<ProviderLocation[]>;
    findMyState(origMeta: StylableMeta, elementName: string, state: string): CSSResolve | null;
    getSignatureHelp(src: string, pos: Position, filePath: string, fs: ExtendedFSReadSync, paramInfo: typeof ParameterInformation): SignatureHelp | null;
    private findWord(word, src, position);
    private escapeRegExp(re);
    private getSignatureForTsModifier(mixin, activeParam, filePath, isDefault, paramInfo);
    private getSignatureForJsModifier(mixin, activeParam, fileSrc, paramInfo);
    private getSignatureForStateWithParamSelector(meta, pos, line);
    private getSignatureForStateWithParamDefinition(meta, pos, line);
    private createProviderOptions(src, position, meta, fakeRules, fullLineText, cursorPosInLine, fs);
    private dedupeComps(completions);
}
export declare function getRefs(params: ReferenceParams, fs: ExtendedFSReadSync, styl: Stylable): Location[];
export declare function getRenameRefs(params: ReferenceParams, fs: ExtendedFSReadSync, styl: Stylable): Location[];
export declare function createMeta(src: string, path: string): {
    meta: null;
    fakes: PostCss.Rule[];
} | {
    meta: StylableMeta;
    fakes: PostCss.Rule[];
};
export declare function fixAndProcess(src: string, position: ProviderPosition, filePath: string): {
    processed: {
        meta: null;
        fakes: PostCss.Rule[];
    } | {
        meta: StylableMeta;
        fakes: PostCss.Rule[];
    };
    currentLine: string;
    cursorLineIndex: number;
};
export declare class ProviderLocation {
    uri: string;
    range: ProviderRange;
    constructor(uri: string, range: ProviderRange);
}
export declare function extractTsSignature(filePath: string, mixin: string, isDefault: boolean, tsLangService: ExtendedTsLanguageService): ts.Signature | undefined;
export declare function extractJsModifierReturnType(mixin: string, activeParam: number, fileSrc: string): string;
export declare function isDirective(line: string): boolean;
export declare function isInValue(lineText: string, position: ProviderPosition): boolean;
export declare function getNamedValues(src: string, lineIndex: number): {
    isNamedValueLine: boolean;
    namedValues: string[];
};
export declare function getExistingNames(lineText: string, position: ProviderPosition): {
    names: string[];
    lastName: string;
};
export declare function getDefSymbol(src: string, position: ProviderPosition, filePath: string, styl: Stylable): {
    word: string;
    meta: StylableMeta | null;
};
