'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const vscode_languageserver_1 = require("vscode-languageserver");
const provider_factory_1 = require("./provider-factory");
const vscode_languageserver_protocol_1 = require("vscode-languageserver-protocol");
const uri_utils_1 = require("./utils/uri-utils");
const service_1 = require("./service");
const core_1 = require("@stylable/core");
const ts = require("typescript");
const temp_language_service_host_1 = require("./utils/temp-language-service-host");
function createDocFs(fileSystem, docs) {
    return {
        __proto__: fileSystem,
        loadTextFile(path) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.loadTextFileSync(path);
            });
        },
        loadTextFileSync(path) {
            const vscodePath = uri_utils_1.toVscodePath(path);
            const fromDocs = docs.get(vscodePath);
            return fromDocs ? fromDocs.getText() : fileSystem.loadTextFileSync(uri_utils_1.fromVscodePath(path));
        },
        loadDirectoryTreeSync(path) {
            return fileSystem.loadDirectoryTreeSync(path);
        },
        get(path) {
            return docs.get(path) || vscode_languageserver_1.TextDocument.create(path, 'stylable', 0, this.loadTextFileSync(uri_utils_1.fromVscodePath(path)));
        },
        getOpenedFiles() {
            return docs.keys();
        }
    };
}
exports.createDocFs = createDocFs;
function init(fileSystem, connection, basePath = '/') {
    const docs = new vscode_languageserver_1.TextDocuments();
    docs.listen(connection);
    const docFs = createDocFs(fileSystem, docs);
    const styl = new core_1.Stylable(basePath, provider_factory_1.createFs(docFs), require);
    const OpenDocNotificationType = new vscode_languageserver_1.NotificationType('stylable/openDocumentNotification');
    let openedFiles = [];
    const tsLanguageServiceHost = temp_language_service_host_1.createLanguageServiceHost({
        cwd: '/',
        getOpenedDocs: () => openedFiles,
        compilerOptions: {
            target: ts.ScriptTarget.ES5, sourceMap: false, declaration: true, outDir: 'dist',
            lib: [],
            module: ts.ModuleKind.CommonJS,
            typeRoots: ["./node_modules/@types"]
        },
        defaultLibDirectory: '',
        baseHost: temp_language_service_host_1.createBaseHost(docFs, path)
    });
    const tsLanguageService = ts.createLanguageService(tsLanguageServiceHost);
    const wrappedTs = {
        setOpenedFiles: (files) => openedFiles = files,
        ts: tsLanguageService
    };
    service_1.initStylableLanguageService(connection, { styl, tsLanguageService: wrappedTs, requireModule: require }, docFs, docs, {
        openDoc: OpenDocNotificationType,
        colorPresentationRequest: vscode_languageserver_protocol_1.ColorPresentationRequest,
        colorRequest: vscode_languageserver_protocol_1.DocumentColorRequest
    });
}
exports.init = init;
//# sourceMappingURL=server-utils.js.map