"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function isInNode(position, node, includeSelector = false) {
    if (!node.source) {
        return false;
    }
    if (!node.source.start) {
        return false;
    }
    if (node.source.start.line > position.line) {
        return false;
    }
    if (node.source.start.line === position.line && node.source.start.column > position.character) {
        return false;
    }
    if (!node.source.end) {
        return !isBeforeRuleset(position, node) || (!!node.nodes && !!(node.nodes.length > 0));
    }
    if (node.source.end.line < position.line) {
        return false;
    }
    if (node.source.end.line === position.line && node.source.end.column < position.character) {
        return false;
    }
    if (isBeforeRuleset(position, node) && !includeSelector) {
        return false;
    }
    if (isAfterRuleset(position, node)) {
        return false;
    }
    return true;
}
exports.isInNode = isInNode;
function isBeforeRuleset(position, node) {
    const part = node.source.input.css.split('\n').slice(node.source.start.line - 1, node.source.end ? node.source.end.line : undefined);
    if (part.findIndex(s => s.indexOf('{') !== -1) + node.source.start.line > position.line) {
        return true;
    }
    if (part[position.line - node.source.start.line].indexOf('{') >= position.character) {
        return true;
    }
    return false;
}
exports.isBeforeRuleset = isBeforeRuleset;
function isAfterRuleset(position, node) {
    const part = node.source.input.css.split('\n').slice(node.source.start.line - 1, node.source.end.line);
    if (part.findIndex(s => s.indexOf('}') !== -1) + node.source.start.line < position.line) {
        return true;
    }
    if (part[position.line - node.source.start.line].indexOf('}') > -1 &&
        part[position.line - node.source.start.line].indexOf('}') < position.character) {
        return true;
    }
    return false;
}
exports.isAfterRuleset = isAfterRuleset;
function isContainer(node) {
    return node.hasOwnProperty('nodes');
}
exports.isContainer = isContainer;
function isSelector(node) {
    return node.hasOwnProperty('selector');
}
exports.isSelector = isSelector;
function isVars(node) {
    return node.hasOwnProperty('selector') && node.selector === ':vars';
}
exports.isVars = isVars;
function isDeclaration(node) {
    return node.hasOwnProperty('prop');
}
exports.isDeclaration = isDeclaration;
function isComment(node) {
    return node.hasOwnProperty('type') && node.type === 'comment';
}
exports.isComment = isComment;
function isRoot(node) {
    return node.hasOwnProperty('type') && node.type === 'root';
}
exports.isRoot = isRoot;
function pathFromPosition(ast, position, res = [], includeSelector = false) {
    let currentNode = ast;
    res.push(ast);
    if (isContainer(currentNode) && currentNode.nodes) {
        const childNode = currentNode.nodes.find((node) => {
            return isInNode(position, node, includeSelector);
        });
        if (childNode) {
            return pathFromPosition(childNode, position, res, includeSelector);
        }
    }
    return res;
}
exports.pathFromPosition = pathFromPosition;
function getPositionInSrc(src, position) {
    const lines = src.split('\n');
    return lines.slice(0, position.line)
        .reduce((total, line) => line.length + total + 1, -1) + position.character;
}
exports.getPositionInSrc = getPositionInSrc;
//# sourceMappingURL=postcss-ast-utils.js.map