"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
const kissfs_1 = require("kissfs");
function createBaseHost(syncFs, systemPath) {
    //TODO: support in kissfs.
    const useCaseSensitiveFileNames = false;
    return { syncFs, useCaseSensitiveFileNames, readDirectory, fileExists, readFile, path: systemPath };
    function readFile(filePath) {
        try {
            return syncFs.loadTextFileSync(filePath);
        }
        catch (_a) {
            return undefined;
        }
    }
    function readDirectory(rootDir, extensions, excludes, includes, depth) {
        return ts.matchFiles(rootDir, extensions, excludes, includes, useCaseSensitiveFileNames, rootDir, depth, getFileSystemEntries);
    }
    function getFileSystemEntries(path) {
        const files = [];
        const directories = [];
        const entries = syncFs.loadDirectoryChildrenSync(path);
        for (const entry of entries) {
            if (entry.type == "file") {
                files.push(entry.name);
            }
            else {
                directories.push(entry.name);
            }
        }
        return { files, directories };
    }
    function fileExists(fullPath) {
        try {
            syncFs.loadTextFileSync(fullPath);
            return true;
        }
        catch (error) {
            return false;
        }
    }
}
exports.createBaseHost = createBaseHost;
function createLanguageServiceHost(hostOptions) {
    const { baseHost, compilerOptions, getOpenedDocs, cwd, customTransformers, defaultLibDirectory, log, trace, error, getProjectVersion } = hostOptions;
    const { syncFs } = baseHost;
    function getDirectories(path) {
        return syncFs.loadDirectoryChildrenSync(path).filter((child) => child.type === 'dir').map(child => child.name);
    }
    function dirExistsSync(targetPath) {
        return kissfs_1.checkExistsSync('dir', syncFs, targetPath);
    }
    const tempCounters = {};
    function getVersion(targetPath) {
        //add capability to kiss-fs
        if (tempCounters[targetPath] !== undefined) {
            tempCounters[targetPath]++;
        }
        else {
            tempCounters[targetPath] = 0;
        }
        return tempCounters[targetPath];
    }
    return {
        getCompilationSettings: () => compilerOptions,
        getNewLine: () => ts.getNewLineCharacter(compilerOptions),
        getProjectVersion,
        getScriptFileNames: getOpenedDocs,
        // getScriptKind?(fileName: string): ScriptKind;
        getScriptVersion: (filePath) => getVersion(filePath) + '',
        getScriptSnapshot: (filePath) => ts.ScriptSnapshot.fromString(syncFs.loadTextFileSync(filePath)),
        // getLocalizedDiagnosticMessages?(): any;
        // getCancellationToken?(): HostCancellationToken;
        getCurrentDirectory: () => cwd,
        getDefaultLibFileName: (options) => baseHost.path.join(defaultLibDirectory, ts.getDefaultLibFileName(options)),
        log,
        trace,
        error,
        useCaseSensitiveFileNames: () => baseHost.useCaseSensitiveFileNames,
        readDirectory: baseHost.readDirectory,
        readFile: baseHost.readFile,
        fileExists: baseHost.fileExists,
        // getTypeRootsVersion?(): number;
        // resolveModuleNames?(moduleNames: string[], containingFile: string): ResolvedModule[];
        // resolveTypeReferenceDirectives?(
        //     typeDirectiveNames: string[], containingFile: string
        // ): ResolvedTypeReferenceDirective[];
        directoryExists: dirExistsSync,
        getDirectories: getDirectories,
        getCustomTransformers: () => customTransformers
    };
}
exports.createLanguageServiceHost = createLanguageServiceHost;
//# sourceMappingURL=temp-language-service-host.js.map